@@ -4,7 +4,7 @@
 #' @importFrom grDevices adjustcolor rainbow rgb
 #' @importFrom graphics abline boxplot legend lines par plot points segments text matplot title axis mtext barplot hist strwidth
 #' @importFrom quantmod getSymbols
-#' @importFrom Rfast colmeans rowmeans rowsums
+#' @importFrom Rfast colmeans rowmeans rowsums comb_n
 #' @importFrom stats coef cor lm na.omit sd median complete.cases resid uniroot aggregate density hat qnorm model.matrix fivenum acf qt ecdf time approx embed frequency is.ts runif start ts optim quantile optimize dnorm dlnorm dexp dt .preformat.ts
 #' @importFrom stringr str_count
 #' @importFrom utils globalVariables head tail combn flush.console
@@ -35,7 +35,7 @@
       "detectCores","makeCluster","registerDoSEQ","clusterExport", "frollmean", "shift",
       "%dopar%","foreach","stopCluster",
       "%do%", "k", "V1", "residuals", "nns_results", "bias_l", "bias_r",
-      "bias", "conf.intervals", "conf.int.neg", "conf.int.pos"
+      "bias", "conf.intervals", "conf.int.neg", "conf.int.pos", "pred.int", "lower.pred.int", "upper.pred.int"
     ))
 
   requireNamespace("data.table")
